@@ -10,5 +10,5 @@ from svolfit.gridanalysis import gridanalysis
 from svolfit.gridanalysis_correlation import gridanalysis_correlation
 
 from svolfit.estimationstats import estimationstats
-from svolfit.analysis_timeseries import analysis_timeseries
+from svolfit.analysis_timeseries import analysis_timeseries,analysis_timeseries_multiple
 
