@@ -3,6 +3,14 @@ import numpy as np
 from svolfit.gridanalysis import gridanalysis
 from svolfit.timeseries_utils.tsparamstats import tsparamstats
 
+def analysis_timeseries_multiple(NAME,FILENAMES,assetname,obswindow_start,obswindow_finish,windows,stride,NumProcesses, dt, model, method, modeloptions ):
+
+	for filename in FILENAMES:
+		modifier=filename[0:len(filename)-4]
+		analysis_timeseries(NAME+'_'+modifier,filename,assetname,obswindow_start,obswindow_finish,windows,stride,NumProcesses, dt, model, method, modeloptions )
+		
+	return
+
 def analysis_timeseries(NAME,filename,assetname,obswindow_start,obswindow_finish,windows,stride,NumProcesses, dt, model, method, modeloptions ):
 
 #TODO: only one asset series at a time now
