@@ -29,6 +29,8 @@ class Heston_GBM_tree(Heston_tree):
 #                 [rho0, phi]
         self.workingpars_bounds=[(-0.99,0.99),(-np.pi+1.0e-4,np.pi-1.0e-4)]
 
+        self.workingpars_optflag=[True,True]
+
         if 'init' in options:
             self.initpars_reporting(options['init'])
         
@@ -53,25 +55,23 @@ class Heston_GBM_tree(Heston_tree):
 
         return ret
 
-    def workingpars_update(self,workingpars):
-        super().workingpars_update(workingpars)
-
-        if( self.current==False):
+    def update(self):
+        super().update()
         
-            sol_rho0=self.workingpars[0]
-            sol_phi=self.workingpars[1]
+        sol_rho0=self.workingpars[0]
+        sol_phi=self.workingpars[1]
 
-            mu=self.Hestonpars[0] 
-            sigma=self.Hestonpars[1]
-            rho=self.Hestonpars[2]
-            alpha=self.Hestonpars[3] 
-            xi=self.Hestonpars[4]
+        mu=self.Hestonpars[0] 
+        sigma=self.Hestonpars[1]
+        rho=self.Hestonpars[2]
+        alpha=self.Hestonpars[3] 
+        xi=self.Hestonpars[4]
 
-            lncondprob_calc=lambda yasset,u_prev,u_this,lncp: Heston_GBM_lncondassetprob(yasset,u_prev,u_this,self.dt,rho,sigma,mu,alpha,xi,lncp)
-        
-            lncondprob_calc(self.yasset,self.grid_u_grid,self.grid_u_grid[self.grid_i_map+1],self.grid_lncondprob_up)
-            lncondprob_calc(self.yasset,self.grid_u_grid,self.grid_u_grid[self.grid_i_map],self.grid_lncondprob_mid)
-            lncondprob_calc(self.yasset,self.grid_u_grid,self.grid_u_grid[self.grid_i_map-1],self.grid_lncondprob_dn)
+        lncondprob_calc=lambda yasset,u_prev,u_this,lncp: Heston_GBM_lncondassetprob(yasset,u_prev,u_this,self.dt,rho,sigma,mu,alpha,xi,lncp)
+    
+        lncondprob_calc(self.yasset,self.grid_u_grid,self.grid_u_grid[self.grid_i_map+1],self.grid_lncondprob_up)
+        lncondprob_calc(self.yasset,self.grid_u_grid,self.grid_u_grid[self.grid_i_map],self.grid_lncondprob_mid)
+        lncondprob_calc(self.yasset,self.grid_u_grid,self.grid_u_grid[self.grid_i_map-1],self.grid_lncondprob_dn)
 
         return
 
@@ -97,6 +97,8 @@ class Heston_GBM_treeX2(Heston_treeX2):
 #                 [rho0, phi]
         self.workingpars_bounds=[(-0.99,0.99),(-np.pi+1.0e-4,np.pi-1.0e-4)]
         
+        self.workingpars_optflag=[True,True]
+
         return
 
     def get_reportingpars(self):
@@ -118,25 +120,23 @@ class Heston_GBM_treeX2(Heston_treeX2):
 
         return ret
 
-    def workingpars_update(self,workingpars):
-        super().workingpars_update(workingpars)
+    def update(self):
+        super().update()
 
-        if( self.current==False):
-        
-            sol_rho0=self.workingpars[0]
-            sol_phi=self.workingpars[1]
+        sol_rho0=self.workingpars[0]
+        sol_phi=self.workingpars[1]
 
-            mu=self.Hestonpars[0] 
-            sigma=self.Hestonpars[1]
-            rho=self.Hestonpars[2]
-            alpha=self.Hestonpars[3] 
-            xi=self.Hestonpars[4]
+        mu=self.Hestonpars[0] 
+        sigma=self.Hestonpars[1]
+        rho=self.Hestonpars[2]
+        alpha=self.Hestonpars[3] 
+        xi=self.Hestonpars[4]
 
-            lncondprob_calc=lambda yasset,u_prev,u_this,lncp: Heston_GBM_lncondassetprob(yasset,u_prev,u_this,self.dt,rho,sigma,mu,alpha,xi,lncp)
-        
-            lncondprob_calc(self.yasset,self.grid_u_grid,self.grid_u_grid[self.grid_i_map+1],self.grid_lncondprob_up)
-            lncondprob_calc(self.yasset,self.grid_u_grid,self.grid_u_grid[self.grid_i_map],self.grid_lncondprob_mid)
-            lncondprob_calc(self.yasset,self.grid_u_grid,self.grid_u_grid[self.grid_i_map-1],self.grid_lncondprob_dn)
+        lncondprob_calc=lambda yasset,u_prev,u_this,lncp: Heston_GBM_lncondassetprob(yasset,u_prev,u_this,self.dt,rho,sigma,mu,alpha,xi,lncp)
+    
+        lncondprob_calc(self.yasset,self.grid_u_grid,self.grid_u_grid[self.grid_i_map+1],self.grid_lncondprob_up)
+        lncondprob_calc(self.yasset,self.grid_u_grid,self.grid_u_grid[self.grid_i_map],self.grid_lncondprob_mid)
+        lncondprob_calc(self.yasset,self.grid_u_grid,self.grid_u_grid[self.grid_i_map-1],self.grid_lncondprob_dn)
 
         return
 
@@ -161,6 +161,8 @@ class Heston_GBM_grid(Heston_grid):
 
 #                 [rho0, phi]
         self.workingpars_bounds=[(-0.99,0.99),(-np.pi+1.0e-4,np.pi-1.0e-4)]
+
+        self.workingpars_optflag=[True,True]
         
         return
 
@@ -183,25 +185,23 @@ class Heston_GBM_grid(Heston_grid):
 
         return ret
 
-    def workingpars_update(self,workingpars):
-        super().workingpars_update(workingpars)
+    def update(self):
+        super().update()
 
-        if( self.current==False):
-        
-            sol_rho0=self.workingpars[0]
-            sol_phi=self.workingpars[1]
+        sol_rho0=self.workingpars[0]
+        sol_phi=self.workingpars[1]
 
-            mu=self.Hestonpars[0] 
-            sigma=self.Hestonpars[1]
-            rho=self.Hestonpars[2]
-            alpha=self.Hestonpars[3] 
-            xi=self.Hestonpars[4]
+        mu=self.Hestonpars[0] 
+        sigma=self.Hestonpars[1]
+        rho=self.Hestonpars[2]
+        alpha=self.Hestonpars[3] 
+        xi=self.Hestonpars[4]
 
-            lncondprob_calc=lambda yasset,u_prev,u_this,lncp: Heston_GBM_lncondassetprob(yasset,u_prev,u_this,self.dt,rho,sigma,mu,alpha,xi,lncp)
-        
-            lncondprob_calc(self.yasset,self.grid_u_grid,self.grid_u_grid[self.grid_i_map+1],self.grid_lncondprob_up)
-            lncondprob_calc(self.yasset,self.grid_u_grid,self.grid_u_grid[self.grid_i_map],self.grid_lncondprob_mid)
-            lncondprob_calc(self.yasset,self.grid_u_grid,self.grid_u_grid[self.grid_i_map-1],self.grid_lncondprob_dn)
+        lncondprob_calc=lambda yasset,u_prev,u_this,lncp: Heston_GBM_lncondassetprob(yasset,u_prev,u_this,self.dt,rho,sigma,mu,alpha,xi,lncp)
+    
+        lncondprob_calc(self.yasset,self.grid_u_grid,self.grid_u_grid[self.grid_i_map+1],self.grid_lncondprob_up)
+        lncondprob_calc(self.yasset,self.grid_u_grid,self.grid_u_grid[self.grid_i_map],self.grid_lncondprob_mid)
+        lncondprob_calc(self.yasset,self.grid_u_grid,self.grid_u_grid[self.grid_i_map-1],self.grid_lncondprob_dn)
 
         return
 
